@@ -2,7 +2,14 @@
 # Signed using RSA key 9A5D2D5AA10873B9ABCD92F1D959AEE8875DEEE6
 # This file is part of leetscraper which is released under GPL-2.0 License.
 
-"""Leetscraper, a coding challenge webscraper for leetcode, and other websites!
+"""
+  __             __
+ |  .-----.-----|  |_.-----.----.----.---.-.-----.-----.----.
+ |  |  -__|  -__|   _|__ --|  __|   _|  _  |  _  |  -__|   _|
+ |__|_____|_____|____|_____|____|__| |___._|   __|_____|__|
+                                           |__|
+
+a coding challenge webscraper for leetcode, and other websites!
 
 This module contains the Leetscraper class that when given the name of a supported
 website, will set some attributes that will allow coding challenges to be requested,
@@ -22,7 +29,7 @@ See related docstrings for help.
 import logging
 from subprocess import run
 from sys import platform
-from time import time, sleep
+from time import time
 from json import loads
 from os import getcwd, walk, path, makedirs
 from re import sub
@@ -52,7 +59,7 @@ class Leetscraper:
     being scraped automatically and saved to the current working directory.
     """
 
-    def __init__(self, **kwargs) -> None:
+    def __init__(self, **kwargs):
         supported_website = False
         self.website_name = kwargs.get("website_name", "leetcode.com")
         self.scraped_path = kwargs.get("scraped_path", getcwd())
@@ -125,14 +132,14 @@ class Leetscraper:
                 makedirs(self.scraped_path)
             except Exception as error:
                 self.logger.warning(
-                    "Could not use path %s!: %s.\nUsing %s instead!",
+                    "Could not use path %s! %s. Using %s instead!",
                     self.scraped_path,
                     error,
                     getcwd(),
                 )
                 self.scraped_path = getcwd()
         if self.scrape_limit == 0:
-            message = "scrape_limit is set to 0!"
+            message = "Scrape_limit is set to 0!"
             self.logger.exception(message)
             raise Exception(message)
         try:
@@ -160,7 +167,7 @@ class Leetscraper:
             get_version = str(check_chrome_version.stdout)
             self.chrome_version = sub("[^0-9.]+", "", get_version)
         except Exception as error:
-            message = f"Could not find chrome version! Error: {error}"
+            message = f"Could not find chrome version! {error}"
             self.logger.exception(message)
             raise Exception(message) from error
         self.errors = 0
@@ -188,7 +195,7 @@ class Leetscraper:
             stream_handler.setFormatter(formatting)
             logger.addHandler(file_handler)
             logger.addHandler(stream_handler)
-            logger.debug("Creating log file %s/leetscraper.log", path.dirname(__file__))
+            print(f"Logging start! Log file: {path.dirname(__file__)}/leetscraper.log")
         return logger
 
     def create_webdriver(self) -> webdriver.chrome.webdriver.WebDriver:
@@ -208,14 +215,14 @@ class Leetscraper:
         self.logger.debug("Created %s webdriver for %s", driver.name, self.website_name)
         return driver
 
-    def webdriver_quit(self, driver) -> None:
+    def webdriver_quit(self, driver):
         """Closes the webdriver."""
         self.logger.debug("Closing %s driver", self.website_name)
         driver.quit()
 
     def scraped_problems(self) -> List[str]:
         """Returns a list of all website problems already scraped in the scraped_path."""
-        self.logger.info(
+        self.logger.debug(
             "Checking %s for existing %s problems", self.scraped_path, self.website_name
         )
         start = time()
@@ -237,7 +244,7 @@ class Leetscraper:
                         scraped_problems.append(file.split(".")[0])
         stop = time()
         self.logger.debug(
-            "checking for %s scraped_problems in %s took %s seconds",
+            "Checking for %s scraped_problems in %s took %s seconds",
             self.website_name,
             self.scraped_path,
             int(stop - start),
@@ -261,7 +268,7 @@ class Leetscraper:
                     get_problems.append(
                         [
                             problem["stat"]["question__title_slug"],
-                            self.website_options["difficulty"][  # type: ignore[index]
+                            self.website_options["difficulty"][
                                 problem["difficulty"]["level"]
                             ],
                         ]
@@ -291,7 +298,7 @@ class Leetscraper:
                 for i in range(0, 1001, 50):
                     request = http.request(
                         "GET",
-                        self.website_options["api_url"]  # type: ignore[operator]
+                        self.website_options["api_url"]
                         + category
                         + f"/challenges?offset={i}&limit=50",
                         headers=headers,
@@ -310,11 +317,11 @@ class Leetscraper:
                         break
         if self.website_name == "codewars.com":
             self.logger.info(
-                "**NOTE** codewars can take up to 5 minutes to search all problems!"
+                "**NOTE** codewars can take up to 5 minutes to find all problems!"
             )
             for i in range(0, 999):
                 request = http.request(
-                    "GET", self.website_options["base_url"] + f"?page={i}"  # type: ignore[operator]
+                    "GET", self.website_options["base_url"] + f"?page={i}"
                 )
                 soup = BeautifulSoup(request.data, "html.parser")
                 data = soup.find_all("div", {"class": "list-item-kata"})
@@ -326,14 +333,14 @@ class Leetscraper:
                     break
         stop = time()
         self.logger.debug(
-            "getting list of needed_problems for %s took %s seconds",
+            "Getting list of needed_problems for %s took %s seconds",
             self.website_name,
             int(stop - start),
         )
         http.clear()
         return get_problems
 
-    def scrape_problems(self, needed_problems: List[List[str]]) -> None:
+    def scrape_problems(self, needed_problems: List[List[str]]):
         """Scrapes needed_problems limited by scrape_limit. (All problems if scrape_limit not set)"""
         if self.scrape_limit:
             if self.scrape_limit >= len(needed_problems):
@@ -350,18 +357,21 @@ class Leetscraper:
                 self.create_problem(problem, driver)
             self.webdriver_quit(driver)
             stop = time()
+            if not self.scrape_limit:
+                self.scrape_limit = len(needed_problems)
             self.logger.debug(
-                "scraping %s %s problems took %s seconds",
-                self.scrape_limit if self.scrape_limit else len(needed_problems),
+                "Scraping %s %s problems took %s seconds",
+                self.scrape_limit - self.errors,
                 self.website_name,
                 int(stop - start),
             )
         else:
             self.logger.warning("No %s problems to scrape", self.website_name)
+            return
         if self.errors:
             self.logger.warning(
                 "Scraped %s problems, but %s problems failed! Check leetscraper.log for failed scrapes.",
-                self.scrape_limit
+                self.scrape_limit - self.errors
                 if self.scrape_limit
                 else len(needed_problems) - self.errors,
                 self.errors,
@@ -375,17 +385,16 @@ class Leetscraper:
 
     def create_problem(
         self, problem: List[str], driver: webdriver.chrome.webdriver.WebDriver
-    ) -> None:
+    ):
         """Gets the html source of a problem, filters down to the problem description, creates a file.\n
         Creates files in scraped_path/website_name/DIFFICULTY/problem.md
         """
         try:
-            driver.get(self.website_options["base_url"] + problem[0])  # type: ignore[operator]
-            WebDriverWait(driver, 10).until(
+            driver.get(self.website_options["base_url"] + problem[0])
+            WebDriverWait(driver, 3).until(
                 EC.invisibility_of_element_located((By.ID, "initial-loading")),
                 "Timeout limit reached",
             )
-            sleep(1)
             html = driver.page_source
             soup = BeautifulSoup(html, "html.parser")
             if self.website_name == "leetcode.com":
@@ -446,7 +455,7 @@ class Leetscraper:
                 problem_name = problem[0].split("/")[0]
             if self.website_name == "codewars.com":
                 try:
-                    difficulty = self.website_options["difficulty"][  # type: ignore[index]
+                    difficulty = self.website_options["difficulty"][
                         (
                             int(
                                 soup.find("div", {"class": "inner-small-hex"})
@@ -475,11 +484,11 @@ class Leetscraper:
                 "w",
                 encoding="utf-8",
             ) as file:
-                file.writelines(self.website_options["base_url"] + problem[0] + "\n\n")  # type: ignore[operator]
+                file.writelines(self.website_options["base_url"] + problem[0] + "\n\n")
                 file.writelines(problem_description + "\n")
         except Exception as error:
             self.logger.debug(
-                "\nError occurred while scraping %s%s: %s",
+                "Failed to scrape %s%s %s",
                 self.website_options["base_url"],
                 problem[0],
                 error,
